@@ -360,7 +360,7 @@ class DataPlotterCallback(Callback):
                 
         dtype = self.trainer.network_dtype
         
-        self.trainer.network.eval()
+        #self.trainer.network.eval()
 
         for input_real, output_real in self.inputs_outputs_real:
             inputs_real.append(input_real)
